#!/usr/bin/env python

"""Update, compile and create PDF and HTML from LaTeX file

Usage:
    python update_anuga_user_manual.py <options>
    
Options:
    --no_html: Skip automatic generation of html version
    


This script can for example be run from a cronjob:

  crontab -e

with content 

SHELL=/bin/sh
PATH=/usr/local/sbin:/usr/local/bin:/sbin:/bin:/usr/sbin:/usr/bin:~/bin

# m h dom mon dow command
  42 *  *   *   *  ~/anuga/documentation/user_manual/update_anuga_user_manual.py > ~/anuga/documentation/user_manual/update_anuga.log
#


Note UNIX only
 
"""

from os import system, chdir
from os.path import expanduser

from sys import argv


anugapath = expanduser('~/inundation/anuga_core/documentation/user_manual')
texfiles = ['anuga_user_manual', 'anuga_installation_guide']

chdir(anugapath) # Move to location of LaTeX files 
system('svn update') # Update from svn


do_html = True        
if len(argv) > 1:
    if argv[1] == '--no_html':
        do_html = False
    else:
        msg = 'Unknown option: %s' %argv[1]
        raise Exception(msg)
    
for texfile in texfiles:
    print 'Processing %s' %texfile
    # Compile with LaTeX, makeindex etc
    for i in range(3):
        #system('latex --interaction=nonstopmode %s.tex' %texfile)
        system('pdflatex --interaction=nonstopmode %s.tex' %texfile)
        system('makeindex %s.idx' %texfile)
        system('makeindex mod%s.idx' %texfile)
        system('bibtex %s' %texfile)    

    # Create pdf file
    #system('dvips %s -o %s.ps' %((texfile,)*2))    
    #system('ps2pdf %s.ps' %texfile)    
     
    # Create html pages
    if do_html is True:
        system('latex2html %s' %texfile)
    else:
        print 'Skipping html version for %s as requested' %texfile

